@@ -57,7 +57,7 @@ css_subtract_fixed(const css_fixed x, const css_fixed y) {
 
 static inline css_fixed
 css_divide_fixed(const css_fixed x, const css_fixed y) {
-	int64_t xx = ((int64_t)x << CSS_RADIX_POINT) / y;
+	int64_t xx = ((int64_t)x * (1 << CSS_RADIX_POINT)) / y;
 
 	if (xx < INT_MIN)
 		xx = INT_MIN;
@@ -83,7 +83,7 @@ css_multiply_fixed(const css_fixed x, const css_fixed y) {
 
 static inline css_fixed
 css_int_to_fixed(const int a) {
-	int64_t xx = ((int64_t) a) << CSS_RADIX_POINT;
+	int64_t xx = ((int64_t) a) * (1 << CSS_RADIX_POINT);
 
 	if (xx < INT_MIN)
 		xx = INT_MIN;
@@ -99,10 +99,12 @@ css_float_to_fixed(const float a) {
 	float xx = a * (float) (1 << CSS_RADIX_POINT);
 
 	if (xx < INT_MIN)
-		xx = INT_MIN;
+		return INT_MIN;
 
-	if (xx > INT_MAX)
-		xx = INT_MAX;
+	/* Conversion from int to float changes value from
+	 * 2147483647 to 2147483648, so we use >= instead of >. */
+	if (xx >= (float)INT_MAX)
+		return INT_MAX;
 
 	return (css_fixed) xx;
 }
@@ -128,6 +130,8 @@ css_float_to_fixed(const float a) {
 
 /* truncate a fixed point value */
 #define TRUNCATEFIX(a) (a & ~((1 << CSS_RADIX_POINT)- 1 ))
+/* get fractional component of a fixed point value */
+#define FIXFRAC(a) (a & ((1 << CSS_RADIX_POINT)- 1 ))
 
 /* Useful values */
 #define F_PI_2	0x00000648	/* 1.5708 (PI/2) */
